@@ -14,6 +14,7 @@ DIM2_NAME = 'lat'
 nlons = 4; nlats = 3
 VAR1_NAME = 'ragged'
 VAR2_NAME = 'strings'
+VAR3_NAME = 'strings_alt'
 data = np.empty(nlats*nlons,object)
 datas = np.empty(nlats*nlons,object)
 nn = 0
@@ -24,6 +25,7 @@ for n in range(nlats*nlons):
 data = np.reshape(data,(nlats,nlons))
 datas = np.reshape(datas,(nlats,nlons))
 
+
 class VariablesTestCase(unittest.TestCase):
 
     def setUp(self):
@@ -34,12 +36,15 @@ class VariablesTestCase(unittest.TestCase):
         f.createDimension(DIM2_NAME,nlats)
         ragged = f.createVariable(VAR1_NAME, vlen_t,\
                 (DIM2_NAME,DIM1_NAME))
-        strings = f.createVariable(VAR2_NAME, str,\
+        strings = f.createVariable(VAR2_NAME, str,
                 (DIM2_NAME,DIM1_NAME))
+        strings_alt = f.createVariable(VAR3_NAME, datas.astype(str).dtype,
+                                       (DIM2_NAME, DIM1_NAME))
         ragged[:] = data
         ragged[-1,-1] = data[-1,-1]
         strings[:] = datas
         strings[-2,-2] = datas[-2,-2]
+        strings_alt[:] = datas.astype(str)
         f.close()
 
     def tearDown(self):
@@ -51,6 +56,7 @@ class VariablesTestCase(unittest.TestCase):
         f = Dataset(self.file, 'r')
         v = f.variables[VAR1_NAME]
         vs = f.variables[VAR2_NAME]
+        vs_alt = f.variables[VAR3_NAME]
         assert list(f.vltypes.keys()) == [VL_NAME]
         assert f.vltypes[VL_NAME].dtype == VL_BASETYPE
         data2 = v[:]
@@ -59,7 +65,19 @@ class VariablesTestCase(unittest.TestCase):
             for j in range(nlats):
                 assert_array_equal(data2[j,i], data[j,i])
                 assert datas[j,i] == data2s[j,i]
+        assert_array_equal(datas, vs_alt[:])
         f.close()
 
+
+class TestInvalidDataType(unittest.TestCase):
+    def runTest(self):
+        f = Dataset(FILE_NAME, 'w', format='NETCDF3_CLASSIC')
+        f.createDimension('x', 1)
+        with self.assertRaisesRegexp(ValueError, 'strings are only supported'):
+           f.createVariable('foo', str, ('x',))
+        f.close()
+        os.remove(FILE_NAME)
+
+
 if __name__ == '__main__':
     unittest.main()
